.. _research:

Research and contribution
=========================

Research
--------

If you are doing research using PennyLane, please cite the PennyLane paper:

  [Placeholder for PennyLane paper]

We are always open for collaboration; you can contact us at research@xanadu.ai.

Support
-------

- **Source Code:** https://github.com/XanaduAI/pennylane
- **Issue Tracker:** https://github.com/XanaduAI/pennylane/issues

If you are having issues, please let us know by posting the problem on our Github issue tracker.



Contribution
------------

We encourage contributions — simply fork the PennyLane repository, and then make a
`pull request <https://help.github.com/articles/about-pull-requests/>`_ containing your contribution. All contributers to PennyLane will be listed as authors on the releases. **All users who contribute significantly to the code (new plugins, new functionality, etc.) will be listed on the PennyLane arXiv paper.**

We also encourage bug reports, suggestions for new features and enhancements, and even links to cool projects or applications built on PennyLane.

See our `contributions page <https://github.com/XanaduAI/pennylane/blob/master/.github/CONTRIBUTING.md>`_
for more details.
